@@ -1,4 +1,4 @@
-package Dist::Zilla::PluginBundle::Author::Plicease 2.33 {
+package Dist::Zilla::PluginBundle::Author::Plicease 2.34 {
 
   use 5.014;
   use Moose;
@@ -31,7 +31,7 @@ package Dist::Zilla::PluginBundle::Author::Plicease 2.33 {
 
   my %plugin_versions = qw(
     Alien                0.023
-    Author::Plicease.*   2.33
+    Author::Plicease.*   2.34
     OurPkgVersion        0.12
     MinimumPerl          1.006
     InstallGuide         1.200006
@@ -232,7 +232,8 @@ package Dist::Zilla::PluginBundle::Author::Plicease 2.33 {
       'Author::Plicease::MarkDownCleanup' => {
               travis_status => int(defined $self->payload->{travis_status} ? $self->payload->{travis_status} : 0),
         maybe appveyor      => $self->payload->{appveyor},
-        maybe travis_user   => $self->payload->{github_user},
+        maybe travis_user   => $self->payload->{travis_user} // $self->payload->{github_user},
+        maybe appveyor_user => $self->payload->{appveyor_user},
       },
     ]);
 
@@ -331,7 +332,7 @@ Dist::Zilla::PluginBundle::Author::Plicease - Dist::Zilla plugin bundle used by
 
 =head1 VERSION
 
-version 2.33
+version 2.34
 
 =head1 SYNOPSIS
 
@@ -522,6 +523,14 @@ Set the GitHub repo name to something other than the dist name.
 
 Set the GitHub user name.
 
+=head2 travis_user
+
+Set the travis user name (defaults to github_user).
+
+=head2 appveyor_user
+
+Set the appveyor username.
+
 =head2 copy_mb
 
 Copy Build.PL from the build into the git repository.
